#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 criterion
version:              1.6.3.0
visibility:           public
id:                   criterion-1.6.3.0-LOIdVYxrEvYJscIHTJJq8Q
key:                  criterion-1.6.3.0-LOIdVYxrEvYJscIHTJJq8Q
license:              BSD-3-Clause
copyright:            2009-2016 Bryan O'\''Sullivan and others
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             http://www.serpentine.com/criterion
synopsis:             Robust, reliable performance measurement and analysis
description:
    This library provides a powerful but simple way to measure software
    performance.  It provides both a framework for executing and
    analysing benchmarks and a set of driver functions that makes it
    easy to build and run benchmarks, and to analyse their results.

    The fastest way to get started is to read the
    <http://www.serpentine.com/criterion/tutorial.html online tutorial>,
    followed by the documentation and examples in the "Criterion.Main"
    module.

    For examples of the kinds of reports that criterion generates, see
    <http://www.serpentine.com/criterion the home page>.

category:             Development, Performance, Testing, Benchmarking
abi:                  d168cdc3517069513e3dbe5872df2049
exposed:              True
exposed-modules:
    Criterion Criterion.Analysis Criterion.IO Criterion.IO.Printf
    Criterion.Internal Criterion.Main Criterion.Main.Options
    Criterion.Monad Criterion.Report Criterion.Types

hidden-modules:       Criterion.Monad.Internal Paths_criterion
import-dirs:          /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/criterion-1.6.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-criterion
hs-libraries:         HScriterion-1.6.3.0-LOIdVYxrEvYJscIHTJJq8Q
depends:
    Glob-0.10.2-JgU70AV9J1Z9hdsqakOSol
    aeson-2.2.1.0-4WRExiZ7zbh8CS1DZxw1Qy base-4.18.2.1
    base-compat-batteries-0.14.1-CvmwiUQL9VZzcx1w11QNz binary-0.8.9.1
    binary-orphans-1.0.5-DA0dLSMWdAkIKiergF7LW bytestring-0.11.5.3
    cassava-0.5.4.1-1n6gticg33ZJTQ0SVCiFdy
    code-page-0.2.1-8r7bPp8D9hK7XmJl89SAkA containers-0.6.7
    criterion-measurement-0.2.3.0-3TDlhjQ8aL8LP418sTTBFo
    deepseq-1.4.8.1 directory-1.3.8.5 exceptions-0.10.7
    filepath-1.4.300.1 js-chart-2.9.4.1-Es3f7aYy6XKGmoiCGVJgsO
    microstache-1.0.2.3-DedFq8TGVB2JbM5xRbd6qS mtl-2.3.1
    mwc-random-0.15.2.0-2XvjSfDBCzQ1MGqTjLs5r0
    optparse-applicative-0.18.1.0-7EdJH1WM84m2Q8FpgsqIZk
    parsec-3.1.16.1 prettyprinter-1.7.1-6jg14vIwDos4Lqu7eMpEik
    prettyprinter-ansi-terminal-1.1.3-25dNCVEFp3dGuk7ZV0yUf5
    statistics-0.16.4.0-2g34u9dVexj4fdPineYrsH text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH
    vector-0.13.2.0-5VH4z5LB2hn3qUPNgI7cRE
    vector-algorithms-0.9.1.0-7rg0gg0MF9FL0AXAloYhX1

haddock-interfaces:   /usr/share/doc/haskell-criterion/html/criterion.haddock
haddock-html:         /usr/share/doc/haskell-criterion/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

